@@ -31,10 +31,10 @@ Subclass of C<Git::Gitalist::Object>.
 
 =head1 AUTHORS
 
-See L<Gitalist> for authors.
+See L<Git::Gitalist> for authors.
 
 =head1 LICENSE
 
-See L<Gitalist> for the license.
+See L<Git::Gitalist> for the license.
 
 =cut
