@@ -63,10 +63,10 @@ Role for objects which have a tree - C<Commit> and C<Tree> objects.
 
 =head1 AUTHORS
 
-See L<Gitalist> for authors.
+See L<Git::Gitalist> for authors.
 
 =head1 LICENSE
 
-See L<Gitalist> for the license.
+See L<Git::Gitalist> for the license.
 
 =cut
